@@ -73,7 +73,7 @@ class settingsProperty:
         obj.__dict__[self.name] = value
 
     def __delete__(self, obj):
-        raise AttributeError("Cannot delete attribute %s" % (self.name,))
+        raise AttributeError(f"Cannot delete attribute {self.name}")
 
     @property
     def __doc__(self):
@@ -83,7 +83,7 @@ class settingsProperty:
             if self.show_default
             else "(dynamically calculated)"
         )
-        return "%s\n\ndefault value: ``%s``" % (description, default)
+        return f"{description}\n\ndefault value: ``{default}``"
 
 
 default_variable = DynamicVariable(None)
@@ -114,10 +114,10 @@ class settingsMeta(type):
             )
         elif not (isinstance(value, settingsProperty) or name.startswith("_")):
             raise AttributeError(
-                "Cannot assign hypothesis.settings.%s=%r - the settings "
+                f"Cannot assign hypothesis.settings.{name}={value!r} - the settings "
                 "class is immutable.  You can change the global default "
                 "settings with settings.load_profile, or use @settings(...) "
-                "to decorate your test instead." % (name, value)
+                "to decorate your test instead."
             )
         return type.__setattr__(self, name, value)
 
@@ -139,7 +139,7 @@ class settings(metaclass=settingsMeta):
         if name in all_settings:
             return all_settings[name].default
         else:
-            raise AttributeError("settings has no attribute %s" % (name,))
+            raise AttributeError(f"settings has no attribute {name}")
 
     def __init__(
         self,
@@ -189,7 +189,7 @@ class settings(metaclass=settingsMeta):
         if not callable(test):
             raise InvalidArgument(
                 "settings objects can be called as a decorator with @given, "
-                "but decorated test=%r is not callable." % (test,)
+                f"but decorated test={test!r} is not callable."
             )
         if inspect.isclass(test):
             from hypothesis.stateful import RuleBasedStateMachine
@@ -213,14 +213,11 @@ class settings(metaclass=settingsMeta):
         if hasattr(test, "_hypothesis_internal_settings_applied"):
             # Can't use _hypothesis_internal_use_settings as an indicator that
             # @settings was applied, because @given also assigns that attribute.
+            descr = get_pretty_function_description(test)
             raise InvalidArgument(
-                "%s has already been decorated with a settings object."
-                "\n    Previous:  %r\n    This:  %r"
-                % (
-                    get_pretty_function_description(test),
-                    test._hypothesis_internal_use_settings,
-                    self,
-                )
+                f"{descr} has already been decorated with a settings object.\n"
+                f"    Previous:  {test._hypothesis_internal_use_settings!r}\n"
+                f"    This:  {self!r}"
             )
 
         test._hypothesis_internal_use_settings = self
@@ -279,15 +276,15 @@ class settings(metaclass=settingsMeta):
         raise AttributeError("settings objects are immutable")
 
     def __repr__(self):
-        bits = ("%s=%r" % (name, getattr(self, name)) for name in all_settings)
-        return "settings(%s)" % ", ".join(sorted(bits))
+        bits = sorted(f"{name}={getattr(self, name)!r}" for name in all_settings)
+        return "settings({})".format(", ".join(bits))
 
     def show_changed(self):
         bits = []
         for name, setting in all_settings.items():
             value = getattr(self, name)
             if value != setting.default:
-                bits.append("%s=%r" % (name, value))
+                bits.append(f"{name}={value!r}")
         return ", ".join(sorted(bits, key=len))
 
     @staticmethod
@@ -352,8 +349,8 @@ def _max_examples_validator(x):
     check_type(int, x, name="max_examples")
     if x < 1:
         raise InvalidArgument(
-            "max_examples=%r should be at least one. You can disable example "
-            "generation with the `phases` setting instead." % (x,)
+            f"max_examples={x!r} should be at least one. You can disable "
+            "example generation with the `phases` setting instead."
         )
     return x
 
@@ -406,9 +403,9 @@ def _validate_database(db):
         return db
     raise InvalidArgument(
         "Arguments to the database setting must be None or an instance of "
-        "ExampleDatabase.  Try passing database=ExampleDatabase(%r), or "
+        f"ExampleDatabase.  Try passing database=ExampleDatabase({db!r}), or "
         "construct and use one of the specific subclasses in "
-        "hypothesis.database" % (db,)
+        "hypothesis.database"
     )
 
 
@@ -437,7 +434,7 @@ class Phase(IntEnum):
     shrink = 4
 
     def __repr__(self):
-        return "Phase.%s" % (self.name,)
+        return f"Phase.{self.name}"
 
 
 @unique
@@ -448,7 +445,7 @@ class HealthCheck(Enum):
     """
 
     def __repr__(self):
-        return "%s.%s" % (self.__class__.__name__, self.name)
+        return f"{self.__class__.__name__}.{self.name}"
 
     @classmethod
     def all(cls) -> List["HealthCheck"]:
@@ -505,7 +502,7 @@ class Verbosity(IntEnum):
     debug = 3
 
     def __repr__(self):
-        return "Verbosity.%s" % (self.name,)
+        return f"Verbosity.{self.name}"
 
 
 settings._define_setting(
@@ -520,7 +517,7 @@ def _validate_phases(phases):
     phases = tuple(phases)
     for a in phases:
         if not isinstance(a, Phase):
-            raise InvalidArgument("%r is not a valid phase" % (a,))
+            raise InvalidArgument(f"{a!r} is not a valid phase")
     return tuple(p for p in list(Phase) if p in phases)
 
 
@@ -538,7 +535,7 @@ settings._define_setting(
 def _validate_stateful_step_count(x):
     check_type(int, x, name="stateful_step_count")
     if x < 1:
-        raise InvalidArgument("stateful_step_count=%r must be at least one." % (x,))
+        raise InvalidArgument(f"stateful_step_count={x!r} must be at least one.")
     return x
 
 
@@ -569,8 +566,8 @@ def validate_health_check_suppressions(suppressions):
     for s in suppressions:
         if not isinstance(s, HealthCheck):
             raise InvalidArgument(
-                "Non-HealthCheck value %r of type %s is invalid in suppress_health_check."
-                % (s, type(s).__name__)
+                f"Non-HealthCheck value {s!r} of type {type(s).__name__} "
+                "is invalid in suppress_health_check."
             )
     return suppressions
 
@@ -588,16 +585,16 @@ class duration(datetime.timedelta):
 
     def __repr__(self):
         ms = self.total_seconds() * 1000
-        return "timedelta(milliseconds=%r)" % (int(ms) if ms == int(ms) else ms,)
+        return "timedelta(milliseconds={!r})".format(int(ms) if ms == int(ms) else ms)
 
 
 def _validate_deadline(x):
     if x is None:
         return x
     invalid_deadline_error = InvalidArgument(
-        "deadline=%r (type %s) must be a timedelta object, an integer or float "
-        "number of milliseconds, or None to disable the per-test-case deadline."
-        % (x, type(x).__name__)
+        f"deadline={x!r} (type {type(x).__name__}) must be a timedelta object, "
+        "an integer or float number of milliseconds, or None to disable the "
+        "per-test-case deadline."
     )
     if isinstance(x, (int, float)):
         if isinstance(x, bool):
@@ -606,14 +603,14 @@ def _validate_deadline(x):
             x = duration(milliseconds=x)
         except OverflowError:
             raise InvalidArgument(
-                "deadline=%r is invalid, because it is too large to represent "
-                "as a timedelta. Use deadline=None to disable deadlines." % (x,)
+                f"deadline={x!r} is invalid, because it is too large to represent "
+                "as a timedelta. Use deadline=None to disable deadlines."
             ) from None
     if isinstance(x, datetime.timedelta):
         if x <= datetime.timedelta(0):
             raise InvalidArgument(
-                "deadline=%r is invalid, because it is impossible to meet a "
-                "deadline <= 0. Use deadline=None to disable deadlines." % (x,)
+                f"deadline={x!r} is invalid, because it is impossible to meet a "
+                "deadline <= 0. Use deadline=None to disable deadlines."
             )
         return duration(seconds=x.total_seconds())
     raise invalid_deadline_error
